@@ -18,6 +18,8 @@
 #include "kpagemodel.h"
 #include "loggingcategory.h"
 
+constexpr const auto viewWidth = 300;
+
 using namespace KDEPrivate;
 
 // KPagePlainView
@@ -76,6 +78,11 @@ QRegion KPagePlainView::visualRegionForSelection(const QItemSelection &) const
 KPageListView::KPageListView(QWidget *parent)
     : QListView(parent)
 {
+    if (layoutDirection() == Qt::RightToLeft) {
+        setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags{Qt::LeftEdge}));
+    } else {
+        setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags{Qt::RightEdge}));
+    }
     setViewMode(QListView::ListMode);
     setMovement(QListView::Static);
     setVerticalScrollMode(QListView::ScrollPerPixel);
@@ -110,12 +117,21 @@ void KPageListView::changeEvent(QEvent *event)
     }
 }
 
+void KPageListView::setFlexibleWidth(bool flexibleWidth)
+{
+    m_flexibleWidth = flexibleWidth;
+}
+
 void KPageListView::updateWidth()
 {
     if (!model()) {
         return;
     }
-    setFixedWidth(sizeHintForColumn(0) + verticalScrollBar()->sizeHint().width() + 5);
+    if (m_flexibleWidth) {
+        setFixedWidth(sizeHintForColumn(0) + verticalScrollBar()->sizeHint().width() + 5);
+    } else {
+        setFixedWidth(viewWidth);
+    }
 }
 
 // KPageTreeView
@@ -123,6 +139,11 @@ void KPageListView::updateWidth()
 KPageTreeView::KPageTreeView(QWidget *parent)
     : QTreeView(parent)
 {
+    if (layoutDirection() == Qt::RightToLeft) {
+        setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags{Qt::LeftEdge}));
+    } else {
+        setProperty("_breeze_borders_sides", QVariant::fromValue(QFlags{Qt::RightEdge}));
+    }
     header()->hide();
 }
 
@@ -154,7 +175,7 @@ void KPageTreeView::updateWidth()
         width = qMax(width, sizeHintForColumn(i));
     }
 
-    setFixedWidth(width + 25);
+    setFixedWidth(qMax(viewWidth, width + 25));
 }
 
 void KPageTreeView::expandItems(const QModelIndex &index)
